@@ -70,7 +70,12 @@ class Config(fixtures.Fixture):
         group = kw.pop('group', None)
         enforce_type = kw.pop('enforce_type', True)
         for k, v in kw.items():
-            self.conf.set_override(k, v, group, enforce_type=enforce_type)
+            if enforce_type is False:
+                self.conf.set_override(k, v, group, enforce_type=False)
+            else:
+                # this removes the deprecation warning if you are just
+                # using defaults
+                self.conf.set_override(k, v, group)
 
     def _unregister_config_opts(self):
         for group in self._registered_config_opts:
